@@ -6,7 +6,7 @@ use warnings;
 require Exporter;
 
 use vars qw($VERSION);
-$VERSION = 2015.071402;
+$VERSION = 2015.071403;
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -164,8 +164,7 @@ Read a csv file to a 2D piddle.
 
 WritePDL3DtoCSV
 
-Write a 2D piddle to a CSV file.
-
+Write a 3D piddle to a CSV file.
 
 GetSampleWithoutReplacements
 
@@ -177,14 +176,22 @@ Sets values in a piddle.
 This is required only when a debugger does not support some PDL functions.
 For example with ActiveState Komodo IDE you may need this function when debugging.
 SetValue accepts three variables.
-1. a piddle that needs to be overwritten, lets say A.
-2. a piddle that need to replace A, lets say B.
-3. 0: replace A with B. i.e. A = B
-   1: Add B to A. i.e. A = A + B;
-   2: Substract B from A = A - B
+
+1) a piddle that needs to be overwritten, lets say A.
+2) a piddle that need to replace A, lets say B.
+3) 0: replace A with B. i.e. A = B ;
+   1: Add B to A. i.e. A = A + B ;   
+   2: Substract B from A = A - B.
+   
 It changes A inplace, there for no output arguments are required.
 The defaults is 0.
 
+DEPENDENCIES
+
+This module requires these other modules and libraries:
+
+PDL
+
 =head1 SEE ALSO
 
 Please refer http://pdl.perl.org/ for PDL.
@@ -193,7 +200,7 @@ PDL is very efficeint in terms of memory and execution time.
 
 =head1 AUTHOR
 
-Muthuthanthiri B Thilak L Fernando
+Muthuthanthiri B Thilak Laksiri Fernando
 
 =head1 COPYRIGHT AND LICENSE
 
